## Configuration

```json
{
  "mcpServers": {
    "yourware-mcp": {
      "command": "uvx",
      "args": ["yourware-mcp@latest", "stdio"],
      "env": {}
    }
  }
}
```

## Available environments variables

`YOURWARE_API_KEY` for the API key, you can also let llm config it for you.

